.. module:: enaml.widgets.dock_events

=========================
enaml.widgets.dock_events
=========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DockEvent
    DockItemEvent


.. autoclass:: DockEvent

.. autoclass:: DockItemEvent
